from typing import List, Optional, Union


def pages_converter(raw_pages: List[dict]) -> List['Page']:
    """
    Convert list of raw pages to list of Page objects

    :param raw_pages:
    :return:
    """
    from .page import Page

    return [Page(**page) for page in raw_pages]


def convert_content(value: List[Union[dict, str]]) -> Optional[List[Union[str, 'NodeElement']]]:
    """
    Convert raw content to Python objects

    :param value:
    :return:
    """
    from .node import NodeElement

    if value is None:
        return

    result = []
    for item in value:
        if isinstance(item, dict):
            item = NodeElement(**item)
        result.append(item)
    return result



from typing import List

from attr import ib, s

from .base import TelegraphObject
from .converters import pages_converter
from .page import Page

__all__ = ['PageList']


@s
class PageList(TelegraphObject):
    """
    This object represents a list of Telegraph articles belonging to an account. Most recently created articles first.

    Source: http://telegra.ph/api#PageList
    """

    total_count: int = ib(default=None)
    pages: List[Page] = ib(factory=list, converter=pages_converter)



from attr import ib, s

from .base import TelegraphObject

__all__ = ['PageViews']


@s
class PageViews(TelegraphObject):
    """
    This object represents the number of page views for a Telegraph article.

    Source: http://telegra.ph/api#PageViews
    """
    views: int = ib()
